Snip core
==========

.. automodule:: drain_swamp.snip
   :members:
   :undoc-members:
   :exclude-members: PATTERN_W_ID, TOKEN_START, TOKEN_END, VALIDATE_FAIL, REPLACED, NO_CHANGE, NO_MATCH
   :platform: Unix
   :synopsis: Within a snippet, replace a text block
